==> webpdf-wsclient-2.0.1-sources.jar: net/webpdf/wsclient/schema/operation/ConverterMailType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ConverterMailType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ConverterMailType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="downloadImages" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="adjustFonts" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="attachmentMode" type="{http://schema.webpdf.de/1.0/operation}AttachmentModeType" default="embed" /&gt;
 *       &lt;attribute name="ignoreMissingBodyChunk" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="useBackground" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *       &lt;attribute name="resizeImages" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="resizeTables" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ConverterMailType")
public class ConverterMailType {

    @XmlAttribute(name = "downloadImages")
    protected Boolean downloadImages;
    @XmlAttribute(name = "adjustFonts")
    protected Boolean adjustFonts;
    @XmlAttribute(name = "attachmentMode")
    protected AttachmentModeType attachmentMode;
    @XmlAttribute(name = "ignoreMissingBodyChunk")
    protected Boolean ignoreMissingBodyChunk;
    @XmlAttribute(name = "useBackground")
    protected Boolean useBackground;
    @XmlAttribute(name = "resizeImages")
    protected Boolean resizeImages;
    @XmlAttribute(name = "resizeTables")
    protected Boolean resizeTables;

    /**
     * Gets the value of the downloadImages property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isDownloadImages() {
        if (downloadImages == null) {
            return false;
        } else {
            return downloadImages;
        }
    }

    /**
     * Sets the value of the downloadImages property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setDownloadImages(boolean value) {
        this.downloadImages = value;
    }

    public boolean isSetDownloadImages() {
        return (this.downloadImages!= null);
    }

    public void unsetDownloadImages() {
        this.downloadImages = null;
    }

    /**
     * Gets the value of the adjustFonts property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isAdjustFonts() {
        if (adjustFonts == null) {
            return false;
        } else {
            return adjustFonts;
        }
    }

    /**
     * Sets the value of the adjustFonts property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setAdjustFonts(boolean value) {
        this.adjustFonts = value;
    }

    public boolean isSetAdjustFonts() {
        return (this.adjustFonts!= null);
    }

    public void unsetAdjustFonts() {
        this.adjustFonts = null;
    }

    /**
     * Gets the value of the attachmentMode property.
     * 
     * @return
     *     possible object is
     *     {@link AttachmentModeType }
     *     
     */
    public AttachmentModeType getAttachmentMode() {
        if (attachmentMode == null) {
            return AttachmentModeType.EMBED;
        } else {
            return attachmentMode;
        }
    }

    /**
     * Sets the value of the attachmentMode property.
     * 
     * @param value
     *     allowed object is
     *     {@link AttachmentModeType }
     *     
     */
    public void setAttachmentMode(AttachmentModeType value) {
        this.attachmentMode = value;
    }

    public boolean isSetAttachmentMode() {
        return (this.attachmentMode!= null);
    }

    /**
     * Gets the value of the ignoreMissingBodyChunk property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIgnoreMissingBodyChunk() {
        if (ignoreMissingBodyChunk == null) {
            return false;
        } else {
            return ignoreMissingBodyChunk;
        }
    }

    /**
     * Sets the value of the ignoreMissingBodyChunk property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIgnoreMissingBodyChunk(boolean value) {
        this.ignoreMissingBodyChunk = value;
    }

    public boolean isSetIgnoreMissingBodyChunk() {
        return (this.ignoreMissingBodyChunk!= null);
    }

    public void unsetIgnoreMissingBodyChunk() {
        this.ignoreMissingBodyChunk = null;
    }

    /**
     * Gets the value of the useBackground property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isUseBackground() {
        if (useBackground == null) {
            return true;
        } else {
            return useBackground;
        }
    }

    /**
     * Sets the value of the useBackground property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setUseBackground(boolean value) {
        this.useBackground = value;
    }

    public boolean isSetUseBackground() {
        return (this.useBackground!= null);
    }

    public void unsetUseBackground() {
        this.useBackground = null;
    }

    /**
     * Gets the value of the resizeImages property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isResizeImages() {
        if (resizeImages == null) {
            return false;
        } else {
            return resizeImages;
        }
    }

    /**
     * Sets the value of the resizeImages property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setResizeImages(boolean value) {
        this.resizeImages = value;
    }

    public boolean isSetResizeImages() {
        return (this.resizeImages!= null);
    }

    public void unsetResizeImages() {
        this.resizeImages = null;
    }

    /**
     * Gets the value of the resizeTables property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isResizeTables() {
        if (resizeTables == null) {
            return false;
        } else {
            return resizeTables;
        }
    }

    /**
     * Sets the value of the resizeTables property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setResizeTables(boolean value) {
        this.resizeTables = value;
    }

    public boolean isSetResizeTables() {
        return (this.resizeTables!= null);
    }

    public void unsetResizeTables() {
        this.resizeTables = null;
    }

}

==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/operation/ConverterMailType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p729701_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:p909447_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;These settings are only used for e-mail documents. The "MIME" (eml; RFC-822) and Outlook (msg) e-mail formats are supported.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for ConverterMailType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="ConverterMailType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="downloadImages" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="adjustFonts" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="attachmentMode" type="{http://schema.webpdf.de/1.0/operation}AttachmentModeType" default="embed" />
 *       <attribute name="ignoreMissingBodyChunk" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="useBackground" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *       <attribute name="resizeImages" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="resizeTables" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ConverterMailType")
public class ConverterMailType {

    @XmlAttribute(name = "downloadImages")
    protected Boolean downloadImages;
    @XmlAttribute(name = "adjustFonts")
    protected Boolean adjustFonts;
    @XmlAttribute(name = "attachmentMode")
    protected AttachmentModeType attachmentMode;
    @XmlAttribute(name = "ignoreMissingBodyChunk")
    protected Boolean ignoreMissingBodyChunk;
    @XmlAttribute(name = "useBackground")
    protected Boolean useBackground;
    @XmlAttribute(name = "resizeImages")
    protected Boolean resizeImages;
    @XmlAttribute(name = "resizeTables")
    protected Boolean resizeTables;

    /**
     * Gets the value of the downloadImages property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isDownloadImages() {
        if (downloadImages == null) {
            return false;
        } else {
            return downloadImages;
        }
    }

    /**
     * Sets the value of the downloadImages property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setDownloadImages(boolean value) {
        this.downloadImages = value;
    }

    public boolean isSetDownloadImages() {
        return (this.downloadImages!= null);
    }

    public void unsetDownloadImages() {
        this.downloadImages = null;
    }

    /**
     * Gets the value of the adjustFonts property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isAdjustFonts() {
        if (adjustFonts == null) {
            return false;
        } else {
            return adjustFonts;
        }
    }

    /**
     * Sets the value of the adjustFonts property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setAdjustFonts(boolean value) {
        this.adjustFonts = value;
    }

    public boolean isSetAdjustFonts() {
        return (this.adjustFonts!= null);
    }

    public void unsetAdjustFonts() {
        this.adjustFonts = null;
    }

    /**
     * Gets the value of the attachmentMode property.
     * 
     * @return
     *     possible object is
     *     {@link AttachmentModeType }
     *     
     */
    public AttachmentModeType getAttachmentMode() {
        if (attachmentMode == null) {
            return AttachmentModeType.EMBED;
        } else {
            return attachmentMode;
        }
    }

    /**
     * Sets the value of the attachmentMode property.
     * 
     * @param value
     *     allowed object is
     *     {@link AttachmentModeType }
     *     
     */
    public void setAttachmentMode(AttachmentModeType value) {
        this.attachmentMode = value;
    }

    public boolean isSetAttachmentMode() {
        return (this.attachmentMode!= null);
    }

    /**
     * Gets the value of the ignoreMissingBodyChunk property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIgnoreMissingBodyChunk() {
        if (ignoreMissingBodyChunk == null) {
            return false;
        } else {
            return ignoreMissingBodyChunk;
        }
    }

    /**
     * Sets the value of the ignoreMissingBodyChunk property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIgnoreMissingBodyChunk(boolean value) {
        this.ignoreMissingBodyChunk = value;
    }

    public boolean isSetIgnoreMissingBodyChunk() {
        return (this.ignoreMissingBodyChunk!= null);
    }

    public void unsetIgnoreMissingBodyChunk() {
        this.ignoreMissingBodyChunk = null;
    }

    /**
     * Gets the value of the useBackground property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isUseBackground() {
        if (useBackground == null) {
            return true;
        } else {
            return useBackground;
        }
    }

    /**
     * Sets the value of the useBackground property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setUseBackground(boolean value) {
        this.useBackground = value;
    }

    public boolean isSetUseBackground() {
        return (this.useBackground!= null);
    }

    public void unsetUseBackground() {
        this.useBackground = null;
    }

    /**
     * Gets the value of the resizeImages property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isResizeImages() {
        if (resizeImages == null) {
            return false;
        } else {
            return resizeImages;
        }
    }

    /**
     * Sets the value of the resizeImages property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setResizeImages(boolean value) {
        this.resizeImages = value;
    }

    public boolean isSetResizeImages() {
        return (this.resizeImages!= null);
    }

    public void unsetResizeImages() {
        this.resizeImages = null;
    }

    /**
     * Gets the value of the resizeTables property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isResizeTables() {
        if (resizeTables == null) {
            return false;
        } else {
            return resizeTables;
        }
    }

    /**
     * Sets the value of the resizeTables property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setResizeTables(boolean value) {
        this.resizeTables = value;
    }

    public boolean isSetResizeTables() {
        return (this.resizeTables!= null);
    }

    public void unsetResizeTables() {
        this.resizeTables = null;
    }

}
